searchData={"items":[{"type":"module","title":"EntityFingerprint.Fingerprint","doc":"","ref":"EntityFingerprint.Fingerprint.html"},{"type":"function","title":"EntityFingerprint.Fingerprint.create/1","doc":"Creates a fingerprint for the given entity name. It supports special character, emojis (because we all know that emoji's in company names are coming), and entity types in other non-latin scripts.","ref":"EntityFingerprint.Fingerprint.html#create/1"},{"type":"function","title":"Examples - EntityFingerprint.Fingerprint.create/1","doc":"```\n  iex(1)> EntityFingerprint.create(\"ФИЛИАЛ КОМПАНИИ С ОГРАНИЧЕННОЙ\")\n\n  {:ok,\n  [\n    fingerprint: \"filial kompanii ogranichennoy s\",\n    original: \"ФИЛИАЛ КОМПАНИИ С ОГРАНИЧЕННОЙ\",\n    script: \"cyrillic\"\n  ]}\n\n  iex(2)> EntityFingerprint.create(\"ООО КУРЬЕР-РЕГИОН СТОЛИЦА\")\n\n  {:ok,\n  [\n    fingerprint: \"kurerregion ooo stolitsa\",\n    original: \"ООО КУРЬЕР-РЕГИОН СТОЛИЦА\",\n    script: \"cyrillic\"\n  ]}\n\n  iex(3)> EntityFingerprint.create(\"Google Limited Liability Company\")\n\n  {:ok,\n  [\n    fingerprint: \"google llc\",\n    original: \"Google Limited Liability Company\",\n    script: \"latin\"\n  ]}\n\n  iex(4)> EntityFingerprint.create(\"현대해상화재보험\")\n\n  {:ok,\n  [\n    fingerprint: \"hyeondaehaesanghwajaeboheom\",\n    original: \"현대해상화재보험\",\n    script: \"hangul\"\n  ]}\n\n  iex(5)> EntityFingerprint.create(\" 💩 Limited Liability Company\")\n\n  {:ok,\n  [\n    fingerprint: \"llc poop\",\n    original: \" 💩 Limited Liability Company\",\n    script: \"common\"\n  ]}\n\n  iex(6)> EntityFingerprint.create(\"佐贤鸣智（上海）企业管理咨询有限公司\")\n  {:ok,\n  [\n    fingerprint: \"guanlizixun shanghai zuoxianmingzhi\",\n    original: \"佐贤鸣智（上海）企业管理咨询有限公司\",\n    script: \"han\"\n  ]}\n\n  iex(7)> EntityFingerprint.create(\"Siemens Aktiengesellschaft\")\n{:ok,\n%{\n script: \"latin\",\n original: \"Google Limited Liability Company\",\n fingerprint: \"382621CA5922751BB77F398DD0B3CB1B4EACE596\",\n fingerprint_str: \"google llc\"\n}}\niex(4)> EntityFingerprint.Fingerprint.create(\"현대해상화재보험\")\n{:ok,\n%{\n script: \"hangul\",\n original: \"현대해상화재보험\",\n fingerprint: \"00044613027E2BF63B36225EAFF0EB48352A68E4\",\n fingerprint_str: \"hyeondaehaesanghwajaeboheom\"\n}}\niex(5)> EntityFingerprint.Fingerprint.create(\" 💩 Limited Liability Company\")\n{:ok,\n%{\n script: \"common\",\n original: \" 💩 Limited Liability Company\",\n fingerprint: \"2881722FEEB9C5AB87B7519C8FB711455690C330\",\n fingerprint_str: \"llc poop\"\n}}\niex(6)> EntityFingerprint.Fingerprint.create(\"佐贤鸣智（上海）企业管理咨询有限公司\")\n{:ok,\n%{\n script: \"han\",\n original: \"佐贤鸣智（上海）企业管理咨询有限公司\",\n fingerprint: \"51DDB4F4AA0F7484E7D9AD5CA2A81C4CAFAB5A4C\",\n fingerprint_str: \"guanlizixun shanghai zuoxianmingzhi\"\n}}\niex(7)> EntityFingerprint.Fingerprint.create(\"Siemens Aktiengesellschaft\")\n{:ok,\n%{\n script: \"latin\",\n original: \"Siemens Aktiengesellschaft\",\n fingerprint: \"069BCC150A2D09F1968E220F48B2362A655A7685\",\n fingerprint_str: \"ag siemens\"\n}}\niex(8)> EntityFingerprint.create(\"New York, New York\")\n** (UndefinedFunctionError) function EntityFingerprint.create/1 is undefined (module EntityFingerprint is not available)\n  EntityFingerprint.create(\"New York, New York\")\n  iex:8: (file)\niex(8)> EntityFingerprint.Fingerprint.create(\"New York, New York\")\n{:ok,\n%{\n script: \"latin\",\n original: \"New York, New York\",\n fingerprint: \"DDDD9606DD438582C9642AA4DEB3C013CBC89148\",\n fingerprint_str: \"new york\"\n}}\niex(9)>\n  ```","ref":"EntityFingerprint.Fingerprint.html#create/1-examples"},{"type":"function","title":"Thanks - EntityFingerprint.Fingerprint.create/1","doc":"This library was heavily inspired by the python tool [alephdata/fingerprints](https://github.com/alephdata/fingerprints)\n\n  - A [Google Spreadsheet](https://docs.google.com/spreadsheets/d/1Cw2xQ3hcZOAgnnzejlY5Sv3OeMxKePTqcRhXQU8rCAw/edit?ts=5e7754cf#gid=0) created by OCCRP.\n\n  - The ISO 20275: [Entity Legal Forms Code List](https://www.gleif.org/en/about-lei/code-lists/iso-20275-entity-legal-forms-code-list)\n\n  - Wikipedia also maintains an index of [types of business entity](https://en.wikipedia.org/wiki/Types_of_business_entity).","ref":"EntityFingerprint.Fingerprint.html#create/1-thanks"},{"type":"function","title":"See also - EntityFingerprint.Fingerprint.create/1","doc":"- [Clustering in Depth](https://github.com/OpenRefine/OpenRefine/wiki/Clustering-In-Depth), part of the OpenRefine documentation discussing how to create collisions in data clustering.","ref":"EntityFingerprint.Fingerprint.html#create/1-see-also"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}